Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(90)

Unified Diff: content/browser/frame_host/frame_tree_node.h

Issue 2046733003: Replicate WebInsecureRequestPolicy instead of a bool for strict mixed content checks. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@securitycontext
Patch Set: alexmos@ Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/DEPS ('k') | content/browser/frame_host/frame_tree_node.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/frame_host/frame_tree_node.h
diff --git a/content/browser/frame_host/frame_tree_node.h b/content/browser/frame_host/frame_tree_node.h
index 32e5623448123dde0c9adaebc0aafdd35160b0f4..35da0f83de68265e3f36eadbfb5f31e05ca00b5f 100644
--- a/content/browser/frame_host/frame_tree_node.h
+++ b/content/browser/frame_host/frame_tree_node.h
@@ -18,6 +18,7 @@
#include "content/browser/frame_host/render_frame_host_manager.h"
#include "content/common/content_export.h"
#include "content/common/frame_replication_state.h"
+#include "third_party/WebKit/public/platform/WebInsecureRequestPolicy.h"
#include "third_party/WebKit/public/web/WebFrameOwnerProperties.h"
#include "url/gurl.h"
#include "url/origin.h"
@@ -156,9 +157,9 @@ class CONTENT_EXPORT FrameTreeNode {
// new document comes with a fresh set of CSP http headers).
void ResetContentSecurityPolicy();
- // Sets the current enforcement of strict mixed content checking and
- // notifies proxies about the update.
- void SetEnforceStrictMixedContentChecking(bool should_enforce);
+ // Sets the current insecure request policy, and notifies proxies about the
+ // update.
+ void SetInsecureRequestPolicy(blink::WebInsecureRequestPolicy policy);
// Returns the currently active sandbox flags for this frame. This includes
// flags inherited from parent frames and the currently active flags from the
« no previous file with comments | « content/browser/DEPS ('k') | content/browser/frame_host/frame_tree_node.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698